@@ -2,13 +2,7 @@
 
 /* main.c */
 #include <config.h>
-#include <libintl.h>
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) gettext (String)
-#else
-#define _(String) (String)
-#endif
+#include "gettext.h"
 
 /* command line configurable variables */
 extern char datafile_path[60];          /* location of data files */
