@@ -1,4 +1,4 @@
-/* $Id: methods.c,v 1.3 2001/05/22 20:38:46 kapheine Exp $ */
+/* $Id: methods.c,v 1.2 2001/02/10 00:22:46 kapheine Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -135,7 +135,7 @@ void common_pairs(void) {
 				printf("match [%s:%s]\n", username, password);
 			if (beep)
 				printf("\007");
-			fprintf(log, "match [%s:%s]\n", username, password);
+			fprintf(logfd, "match [%s:%s]\n", username, password);
 			found++;
 		}
 		i++;
@@ -143,7 +143,7 @@ void common_pairs(void) {
 		if (max_users == num_users && max_users != 0) {
 			if (!quiet)
 				printf("max users reached at %i\n", num_users);
-			fprintf(log, "max users reached at %i\n", num_users);
+			fprintf(logfd, "max users reached at %i\n", num_users);
 			break;
 		}
 		num_users++;
